@@ -9,7 +9,7 @@ from matplotlib.gridspec import GridSpec
 from matplotlib.patches import Rectangle
 from mpl_toolkits.axes_grid1 import make_axes_locatable
 from scipy.interpolate import interp1d
-from PlanetProfile.GetConfig import Color, Style, FigLbl, FigSize, FigMisc, InductParams as IndParams
+from PlanetProfile.GetConfig import Color, Style, FigLbl, FigSize, FigMisc
 from PlanetProfile.Utilities.defineStructs import Constants
 from PlanetProfile.MagneticInduction.Moments import Excitations
 from MoonMag.asymmetry_funcs import getMagSurf as GetMagSurf
@@ -62,36 +62,40 @@ def PlotInductOgramPhaseSpace(InductionList, Params):
     if not FigMisc.TEX_INSTALLED:
         FigLbl.StripLatex()
 
-    sigma_Sm, D_km, ptColors = (np.empty_like(InductionList) for _ in range(3))
+    sigma_Sm, D_km, ptColors, w_ppt, yFlat, iValid, iValidFlat \
+        = (np.empty_like(InductionList) for _ in range(7))
     for i, Induction in enumerate(InductionList):
-        sigma_Sm[i] = Induction.sigmaMean_Sm.flatten()
-        D_km[i] = Induction.D_km.flatten()
+        iValid[i] = np.where(np.isfinite(Induction.Amp[0,...]))
+        iValidFlat[i] = np.where(np.isfinite(Induction.Amp[0,...].flatten()))[0]
+        sigma_Sm[i] = Induction.sigmaMean_Sm[iValid[i]].flatten()
+        D_km[i] = Induction.D_km[iValid[i]].flatten()
         if Params.Induct.inductOtype == 'sigma':
             # In this case, we likely don't have salinity and ocean temp information
             # so we need to set the colormap to use the info we do have
             sigmaNorm = sigma_Sm[i] / 10**Params.Induct.sigmaMax[Induction.bodyname]
             Dnorm = D_km[i] / np.max(D_km)
-            ptColors[i] = Color.OceanCmap(Induction.compsList, sigmaNorm, Dnorm,
+            ptColors[i] = Color.OceanCmap(Induction.compsList[iValidFlat[i]], sigmaNorm, Dnorm,
                                           DARKEN_SALINITIES=FigMisc.DARKEN_SALINITIES)
         else:
-            w_ppt = Induction.x.flatten()
-            Tmean_K = Induction.Tmean_K.flatten()
+            w_ppt[i] = Induction.x[iValid[i]].flatten()
+            yFlat[i] = Induction.y[iValid[i]].flatten()
+            Tmean_K = Induction.Tmean_K[iValid[i]].flatten()
             if FigMisc.NORMALIZED_SALINITIES:
-                wMax_ppt = np.array([Color.saturation[comp] for comp in Induction.compsList])
-                w_normFrac = w_ppt / wMax_ppt
+                wMax_ppt = np.array([Color.saturation[comp] for comp in Induction.compsList[iValidFlat[i]]])
+                w_normFrac = w_ppt[i] / wMax_ppt
             else:
-                w_normFrac = interp1d([np.min(w_ppt), np.max(w_ppt)], [0.0, 1.0])(w_ppt)
+                w_normFrac = interp1d([np.min(w_ppt[i]), np.max(w_ppt[i])], [0.0, 1.0])(w_ppt[i])
             if Params.Induct.colorType == 'Tmean':
                 if FigMisc.NORMALIZED_TEMPERATURES:
                     Tmean_normFrac = Color.GetNormT(Tmean_K)
                 else:
                     Tmean_normFrac = interp1d([np.min(Tmean_K), np.max(Tmean_K)], [0.0, 1.0])(Tmean_K)
-                ptColors[i] = Color.OceanCmap(Induction.compsList, w_normFrac, Tmean_normFrac,
+                ptColors[i] = Color.OceanCmap(Induction.compsList[iValidFlat[i]], w_normFrac, Tmean_normFrac,
                                               DARKEN_SALINITIES=FigMisc.DARKEN_SALINITIES)
             elif Params.Induct.colorType == 'zb':
-                zb_km = Induction.zb_km.flatten()
+                zb_km = Induction.zb_km[iValid[i]].flatten()
                 zb_normFrac = interp1d([np.min(zb_km), np.max(zb_km)], [0.0, 1.0])(zb_km)
-                ptColors[i] = Color.OceanCmap(Induction.compsList, w_normFrac, zb_normFrac,
+                ptColors[i] = Color.OceanCmap(Induction.compsList[iValidFlat[i]], w_normFrac, zb_normFrac,
                                               DARKEN_SALINITIES=FigMisc.DARKEN_SALINITIES)
             else:
                 raise ValueError(f'Inductogram colortype {Params.Induct.colorType} not recognized.')
@@ -107,17 +111,15 @@ def PlotInductOgramPhaseSpace(InductionList, Params):
             axes[0].grid()
             axes[0].set_axisbelow(True)
         cbarAx = fig.add_subplot(grid[0, 1])
-        cbarUnits = InductionList[0].zb_km.flatten()
+        cbarUnits = InductionList[0].zb_km[iValid[0]].flatten()
         cbarLabel = FigLbl.iceThickLbl
     else:
         comps = np.unique(InductionList[0].comps)
-        w_ppt = InductionList[0].x.flatten()
-        yFlat = InductionList[0].y.flatten()
         if Params.Induct.colorType == 'Tmean':
-            cbarUnits = InductionList[0].Tmean_K.flatten()
+            cbarUnits = InductionList[0].Tmean_K[iValid[0]].flatten()
             cbarLabel = FigLbl.oceanTempLbl
         elif Params.Induct.colorType == 'zb':
-            cbarUnits = InductionList[0].zb_km.flatten()
+            cbarUnits = InductionList[0].zb_km[iValid[0]].flatten()
             cbarLabel = FigLbl.iceThickLbl
 
         fig = plt.figure(figsize=FigSize.phaseSpaceCombo, constrained_layout=True)
@@ -132,7 +134,7 @@ def PlotInductOgramPhaseSpace(InductionList, Params):
         axes[1].set_ylabel(FigLbl.yLabelInduct)
         axes[1].set_xscale(FigLbl.wScale)
         axes[1].set_yscale(FigLbl.yScaleInduct)
-        axes[1].scatter(w_ppt, yFlat, s=Style.MW_Induction,
+        axes[1].scatter(w_ppt[0], yFlat[0], s=Style.MW_Induction,
                         marker=Style.MS_Induction, c=ptColors[0])
 
     # Labels and titles
@@ -152,7 +154,7 @@ def PlotInductOgramPhaseSpace(InductionList, Params):
         cbar[comps[0]] = fig.colorbar(pts[comps[0]], cax=cbarAx)
     else:
         for comp, cbarAx in zip(comps, cbarAxes):
-            thisComp = InductionList[0].compsList == comp
+            thisComp = InductionList[0].compsList[iValidFlat[0]] == comp
             pts[comp] = axes[0].scatter(sigma_Sm[0][thisComp], D_km[0][thisComp], s=Style.MW_Induction,
                             marker=Style.MS_Induction, c=cbarUnits[thisComp], cmap=Color.cmap[comp])
             cbar[comp] = fig.colorbar(pts[comp], cax=cbarAx)
@@ -161,14 +163,21 @@ def PlotInductOgramPhaseSpace(InductionList, Params):
                 lbl = FigLbl.StripLatexFromString(lbl)
             cbarAx.set_title(lbl, fontsize=FigMisc.cbarTitleSize)
 
+            if FigMisc.MARK_INDUCT_BOUNDS:
+                boundStyle = {'ls': Style.LS_BdipInset, 'lw': Style.LW_BdipInset, 'c': Color.BdipInset}
+                _ = axes[0].plot(sigma_Sm[0][thisComp][w_ppt[0] == np.min(w_ppt[0])], D_km[0][thisComp][w_ppt[0] == np.min(w_ppt[0])], **boundStyle)
+                _ = axes[0].plot(sigma_Sm[0][thisComp][w_ppt[0] == np.max(w_ppt[0])], D_km[0][thisComp][w_ppt[0] == np.max(w_ppt[0])], **boundStyle)
+                _ = axes[0].plot(sigma_Sm[0][thisComp][yFlat[0] == np.min(yFlat[0])], D_km[0][thisComp][yFlat[0] == np.min(yFlat[0])], **boundStyle)
+                _ = axes[0].plot(sigma_Sm[0][thisComp][yFlat[0] == np.max(yFlat[0])], D_km[0][thisComp][yFlat[0] == np.max(yFlat[0])], **boundStyle)
+
     cbar[comps[-1]].set_label(cbarLabel)
-    fig.savefig(Params.FigureFiles.phaseSpace, format=FigMisc.figFormat, dpi=FigMisc.dpi)
+    fig.savefig(Params.FigureFiles.phaseSpace, format=FigMisc.figFormat, dpi=FigMisc.dpi, metadata=FigLbl.meta)
     log.debug(f'InductOgram phase space plot saved to file: {Params.FigureFiles.phaseSpace}')
     plt.close()
 
     # Plot combination
     if Params.COMPARE and np.size(InductionList) > 1 and Params.Induct.inductOtype != 'sigma':
-        comps = np.unique(np.append([],[Induction.comps for Induction in InductionList]))
+        comps = np.unique(np.append([], [Induction.comps for Induction in InductionList]))
         nComps = np.size(comps)
         figWidth = FigSize.phaseSpaceSolo[0] + nComps * FigMisc.cbarSpace
         fig, ax = plt.subplots(1, 1, figsize=(figWidth, FigSize.phaseSpaceSolo[1]))
@@ -191,16 +200,18 @@ def PlotInductOgramPhaseSpace(InductionList, Params):
         comboSigma_Sm = np.concatenate(tuple(sigmai for sigmai in sigma_Sm))
         comboD_km = np.concatenate(tuple(Di for Di in D_km))
         comboColors = np.concatenate(tuple(ptColi for ptColi in ptColors))
+        combow_ppt = np.concatenate(tuple(wi for wi in w_ppt))
+        comboyFlat = np.concatenate(tuple(yi for yi in yFlat))
         if Params.Induct.colorType == 'Tmean':
-            comboCbarUnits = np.concatenate(tuple(Induction.Tmean_K.flatten() for Induction in InductionList))
+            comboCbarUnits = np.concatenate(tuple(Induction.Tmean_K[iValid[i]].flatten() for i,Induction in enumerate(InductionList)))
         elif Params.Induct.colorType == 'zb':
-            comboCbarUnits = np.concatenate(tuple(Induction.zb_km.flatten() for Induction in InductionList))
+            comboCbarUnits = np.concatenate(tuple(Induction.zb_km[iValid[i]].flatten() for i,Induction in enumerate(InductionList)))
         pts = {}
         for comp in comps:
             thisComp = comboCompsList == comp
             pts[comp] = ax.scatter(comboSigma_Sm[thisComp], comboD_km[thisComp], s=Style.MW_Induction,
                                         marker=Style.MS_Induction, c=comboColors[thisComp])
-            cbarAx = divider.new_horizontal(size=FigMisc.cbarSize, pad=FigMisc.cbarPad + extraPad)
+            cbarAx = divider.new_horizontal(size=FigMisc.cbarSize, pad=FigMisc.cbarSpace + extraPad)
             extraPad = FigMisc.extraPad
             cbar = mcbar.ColorbarBase(cbarAx, cmap=Color.cmap[comp], format=FigMisc.cbarFmt,
                                       values=np.linspace(np.min(comboCbarUnits[thisComp]), np.max(comboCbarUnits[thisComp]), FigMisc.nCbarPts))
@@ -210,9 +221,18 @@ def PlotInductOgramPhaseSpace(InductionList, Params):
                 lbl = FigLbl.StripLatexFromString(lbl)
             cbarAx.set_title(lbl, fontsize=FigMisc.cbarTitleSize)
 
+            if FigMisc.MARK_INDUCT_BOUNDS:
+                thisw_ppt = combow_ppt[thisComp]
+                thisyFlat = comboyFlat[thisComp]
+                boundStyle = {'ls': Style.LS_BdipInset, 'lw': Style.LW_BdipInset, 'c': Color.BdipInset}
+                _ = ax.plot(comboSigma_Sm[thisComp][thisw_ppt == np.min(thisw_ppt)], comboD_km[thisComp][thisw_ppt == np.min(thisw_ppt)], **boundStyle)
+                _ = ax.plot(comboSigma_Sm[thisComp][thisw_ppt == np.max(thisw_ppt)], comboD_km[thisComp][thisw_ppt == np.max(thisw_ppt)], **boundStyle)
+                _ = ax.plot(comboSigma_Sm[thisComp][thisyFlat == np.min(thisyFlat)], comboD_km[thisComp][thisyFlat == np.min(thisyFlat)], **boundStyle)
+                _ = ax.plot(comboSigma_Sm[thisComp][thisyFlat == np.max(thisyFlat)], comboD_km[thisComp][thisyFlat == np.max(thisyFlat)], **boundStyle)
+
         cbar.set_label(cbarLabel, size=12)
         plt.tight_layout()
-        fig.savefig(Params.FigureFiles.phaseSpaceCombo, format=FigMisc.figFormat, dpi=FigMisc.dpi)
+        fig.savefig(Params.FigureFiles.phaseSpaceCombo, format=FigMisc.figFormat, dpi=FigMisc.dpi, metadata=FigLbl.meta)
         log.debug(f'Plot saved to file: {Params.FigureFiles.phaseSpaceCombo}')
         plt.close()
 
@@ -228,18 +248,39 @@ def PlotInductOgram(Induction, Params):
     TexcCalcd = excSelectionCalc and Induction.Texc_hr
     whichTexc = excSelectionCalc and Params.Induct.excSelectionPlot
     allTexc_hr = np.fromiter(TexcCalcd.values(), dtype=np.float_)
-    allTexc_hr = allTexc_hr[np.isfinite(allTexc_hr)]
-    iTexc = [np.where(allTexc_hr == Texc)[0][0] for key, Texc in TexcCalcd.items() if whichTexc[key]]
+    allAvailableTexc_hr = allTexc_hr[np.isfinite(allTexc_hr)]
+    iTexc = [np.where(allTexc_hr == Texc)[0][0] for key, Texc in TexcCalcd.items() if whichTexc[key] and np.size(np.where(allTexc_hr == Texc)[0]) > 0]
+    iTexcAvail = [np.where(allAvailableTexc_hr == Texc)[0][0] for key, Texc in TexcCalcd.items() if whichTexc[key] and np.size(np.where(allAvailableTexc_hr == Texc)[0]) > 0]
     TexcPlotNames = np.fromiter(Induction.Texc_hr.keys(), dtype='<U20')[iTexc]
     Texc_hr = allTexc_hr[iTexc]
     iSort = np.argsort(Texc_hr)
+    if Induction.bodyname not in Params.Induct.sigmaMax.keys() or Induction.bodyname not in Params.Induct.sigmaMin.keys():
+        sigmaMin = np.min(Induction.sigmaMean_Sm[np.isfinite(Induction.sigmaMean_Sm)])
+        sigmaMax = np.max(Induction.sigmaMean_Sm[np.isfinite(Induction.sigmaMean_Sm)])
+        Dmin = np.min(Induction.D_km[np.isfinite(Induction.D_km)])
+        Dmax = np.max(Induction.D_km[np.isfinite(Induction.D_km)])
+        log.warning(f'At least one of [sigmaMin, sigmaMax, Dmin, Dmax] are not set for {Induction.bodyname} in configPPinduct. ' +
+                    f'Using min/max for this inductOgram run:\n' +
+                    f'sigmaMin: {sigmaMin} S/m\n' +
+                    f'sigmaMin: {sigmaMax} S/m\n' +
+                    f'sigmaMin: {Dmin} S/m\n' +
+                    f'sigmaMin: {Dmax} S/m\n')
+        Params.Induct.sigmaMin[Induction.bodyname] = np.log10(sigmaMin)
+        Params.Induct.sigmaMax[Induction.bodyname] = np.log10(sigmaMax)
+        Params.Induct.Dmin[Induction.bodyname] = np.log10(Dmin)
+        Params.Induct.Dmax[Induction.bodyname] = np.log10(Dmax)
+        
+    # Let matplotlib decide contour levels and format if we haven't explicitly set them
+    if Induction.bodyname not in Params.Induct.cLevels.keys() or Induction.bodyname not in Params.Induct.cFmt.keys():
+        Params.Induct.SPECIFIC_CLEVELS = False
+        
     FigLbl.SetInduction(Induction.bodyname, Params.Induct, Texc_hr)
     if not FigMisc.TEX_INSTALLED:
         FigLbl.StripLatex()
 
     # Get all common labels and data for zipping
-    zData = [Induction.Amp[iTexc,...], np.abs(Induction.Bix_nT[iTexc,...]),
-             np.abs(Induction.Biy_nT[iTexc,...]), np.abs(Induction.Biz_nT[iTexc,...])]
+    zData = [Induction.Amp[iTexcAvail,...], np.abs(Induction.Bix_nT[iTexcAvail,...]),
+             np.abs(Induction.Biy_nT[iTexcAvail,...]), np.abs(Induction.Biz_nT[iTexcAvail,...])]
     if Induction.SINGLE_COMP:
         FigLbl.singleComp(Induction.comps[0])
 
@@ -267,8 +308,8 @@ def PlotInductOgram(Induction, Params):
         [ax.set_xscale(FigLbl.sigScale) for ax in allAxes]
         [ax.set_yscale(FigLbl.Dscale) for ax in allAxes]
         coords = {'Bx': (0,0), 'By': (0,1), 'Bz': (1,0), 'phase': (1,1)}
-        comboData = [np.abs(Induction.Bix_nT[iTexc,...]), np.abs(Induction.Biy_nT[iTexc,...]),
-                     np.abs(Induction.Biz_nT[iTexc,...]), Induction.phase[iTexc,...]]
+        comboData = [np.abs(Induction.Bix_nT[iTexcAvail,...]), np.abs(Induction.Biy_nT[iTexcAvail,...]),
+                     np.abs(Induction.Biz_nT[iTexcAvail,...]), Induction.phase[iTexcAvail,...]]
         comboTitles = np.append(FigLbl.plotTitles[1:], FigLbl.phaseTitle)
         comboLabels = list(coords.keys())
 
@@ -277,12 +318,18 @@ def PlotInductOgram(Induction, Params):
             ax.set_title(name)
             zContours = [ax.contour(Induction.sigmaMean_Sm, Induction.D_km, z[i, ...],
                            colors=Color.Induction[T], linestyles=Style.LS_Induction[T],
-                           linewidths=Style.LW_Induction[T], levels=IndParams.GetClevels(fLabel, T))
+                           linewidths=Style.LW_Induction[T], levels=Params.Induct.GetClevels(fLabel, T))
                            for i, T in enumerate(TexcPlotNames)]
             if Params.Induct.inductOtype == 'sigma':
-                [ax.clabel(zContours[i], fmt=IndParams.GetCfmt(fLabel, T),
+                [ax.clabel(zContours[i], fmt=Params.Induct.GetCfmt(fLabel, T),
                            fontsize=FigMisc.cLabelSize, inline_spacing=FigMisc.cLabelPad)
                            for i, T in enumerate(TexcPlotNames)]
+            elif FigMisc.MARK_INDUCT_BOUNDS:
+                boundStyle = {'ls': Style.LS_BdipInset, 'lw': Style.LW_BdipInset, 'c': Color.BdipInset}
+                _ = ax.plot(Induction.sigmaMean_Sm[Induction.x == np.min(Induction.x)], Induction.D_km[Induction.x == np.min(Induction.x)], **boundStyle)
+                _ = ax.plot(Induction.sigmaMean_Sm[Induction.x == np.max(Induction.x)], Induction.D_km[Induction.x == np.max(Induction.x)], **boundStyle)
+                _ = ax.plot(Induction.sigmaMean_Sm[Induction.y == np.min(Induction.y)], Induction.D_km[Induction.y == np.min(Induction.y)], **boundStyle)
+                _ = ax.plot(Induction.sigmaMean_Sm[Induction.y == np.max(Induction.y)], Induction.D_km[Induction.y == np.max(Induction.y)], **boundStyle)
 
         if FigMisc.PLOT_V2021 and Induction.bodyname in ['Europa', 'Ganymede', 'Callisto']:
             AddV2021points(Params.Induct, Induction.bodyname, 'sigma', allAxes)
@@ -297,7 +344,7 @@ def PlotInductOgram(Induction, Params):
             fNameSigma = Params.FigureFiles.sigma['Bcomps']
 
         plt.tight_layout()
-        fig.savefig(fNameSigma, format=FigMisc.figFormat, dpi=FigMisc.dpi)
+        fig.savefig(fNameSigma, format=FigMisc.figFormat, dpi=FigMisc.dpi, metadata=FigLbl.meta)
         log.debug(f'Plot saved to file: {fNameSigma}')
         plt.close()
 
@@ -323,9 +370,9 @@ def PlotInductOgram(Induction, Params):
                 zContours = [ax.contour(Induction.x, Induction.y, z[i, ...],
                                         colors=Color.Induction[T], linestyles=Style.LS_Induction[T],
                                         linewidths=Style.LW_Induction[T],
-                                        levels=IndParams.GetClevels(fLabel, T))
+                                        levels=Params.Induct.GetClevels(fLabel, T))
                              for i, T in enumerate(TexcPlotNames)]
-                [ax.clabel(zContours[i], fmt=IndParams.GetCfmt(fLabel, T),
+                [ax.clabel(zContours[i], fmt=Params.Induct.GetCfmt(fLabel, T),
                            fontsize=FigMisc.cLabelSize, inline_spacing=FigMisc.cLabelPad)
                            for i, T in enumerate(TexcPlotNames)]
 
@@ -336,8 +383,15 @@ def PlotInductOgram(Induction, Params):
                 lines = np.array([contour.legend_elements()[0][0] for contour in zContours])
                 axes[1,1].legend(lines[iSort], FigLbl.legendTexc[iSort], framealpha=FigMisc.cLegendOpacity)
 
+            if FigMisc.MARK_INDUCT_BOUNDS:
+                boundStyle = {'ls': Style.LS_BdipInset, 'lw': Style.LW_BdipInset, 'c': Color.BdipInset}
+                _ = [ax.plot(Induction.sigmaMean_Sm[Induction.x == np.min(Induction.x)], Induction.D_km[Induction.x == np.min(Induction.x)], **boundStyle) for ax in allAxes]
+                _ = [ax.plot(Induction.sigmaMean_Sm[Induction.x == np.max(Induction.x)], Induction.D_km[Induction.x == np.max(Induction.x)], **boundStyle) for ax in allAxes]
+                _ = [ax.plot(Induction.sigmaMean_Sm[Induction.y == np.min(Induction.y)], Induction.D_km[Induction.y == np.min(Induction.y)], **boundStyle) for ax in allAxes]
+                _ = [ax.plot(Induction.sigmaMean_Sm[Induction.y == np.max(Induction.y)], Induction.D_km[Induction.y == np.max(Induction.y)], **boundStyle) for ax in allAxes]
+
             plt.tight_layout()
-            fig.savefig(Params.FigureFiles.induct['Bcomps'], format=FigMisc.figFormat, dpi=FigMisc.dpi)
+            fig.savefig(Params.FigureFiles.induct['Bcomps'], format=FigMisc.figFormat, dpi=FigMisc.dpi, metadata=FigLbl.meta)
             log.debug(f'Plot saved to file: {Params.FigureFiles.induct["Bcomps"]}')
             plt.close()
 
@@ -371,27 +425,27 @@ def PlotInductOgram(Induction, Params):
             zContours = [axes[0,0].contour(Induction.x, Induction.y, comboData[0][i, ...],
                                     colors=Color.Induction[T], linestyles=Style.LS_Induction[T],
                                     linewidths=Style.LW_Induction[T],
-                                    levels=IndParams.GetClevels(comboLabels[0], T))
+                                    levels=Params.Induct.GetClevels(comboLabels[0], T))
                          for i, T in enumerate(TexcPlotNames)]
             phaseContours = [axes[0,1].contour(Induction.x, Induction.y, comboData[-1][i, ...],
                                     colors=Color.Induction[T], linestyles=Style.LS_Induction[T],
                                     linewidths=Style.LW_Induction[T],
-                                    levels=IndParams.GetClevels(comboLabels[-1], T))
+                                    levels=Params.Induct.GetClevels(comboLabels[-1], T))
                          for i, T in enumerate(TexcPlotNames)]
             [axes[1,0].contour(Induction.sigmaMean_Sm, Induction.D_km, comboData[0][i, ...],
                                     colors=Color.Induction[T], linestyles=Style.LS_Induction[T],
                                     linewidths=Style.LW_Induction[T],
-                                    levels=IndParams.GetClevels(comboLabels[0], T))
+                                    levels=Params.Induct.GetClevels(comboLabels[0], T))
                          for i, T in enumerate(TexcPlotNames)]
             [axes[1,1].contour(Induction.sigmaMean_Sm, Induction.D_km, comboData[-1][i, ...],
                                     colors=Color.Induction[T], linestyles=Style.LS_Induction[T],
                                     linewidths=Style.LW_Induction[T],
-                                    levels=IndParams.GetClevels(comboLabels[-1], T))
+                                    levels=Params.Induct.GetClevels(comboLabels[-1], T))
                          for i, T in enumerate(TexcPlotNames)]
-            [axes[0,0].clabel(zContours[i], fmt=IndParams.GetCfmt(comboLabels[0], T),
+            [axes[0,0].clabel(zContours[i], fmt=Params.Induct.GetCfmt(comboLabels[0], T),
                        fontsize=FigMisc.cLabelSize, inline_spacing=FigMisc.cLabelPad)
                        for i, T in enumerate(TexcPlotNames)]
-            [axes[0,1].clabel(phaseContours[i], fmt=IndParams.GetCfmt(comboLabels[-1], T),
+            [axes[0,1].clabel(phaseContours[i], fmt=Params.Induct.GetCfmt(comboLabels[-1], T),
                        fontsize=FigMisc.cLabelSize, inline_spacing=FigMisc.cLabelPad)
                        for i, T in enumerate(TexcPlotNames)]
 
@@ -403,8 +457,15 @@ def PlotInductOgram(Induction, Params):
                 lines = np.array([contour.legend_elements()[0][0] for contour in zContours])
                 axes[1,1].legend(lines[iSort], FigLbl.legendTexc[iSort], framealpha=FigMisc.cLegendOpacity)
 
+            if FigMisc.MARK_INDUCT_BOUNDS:
+                boundStyle = {'ls': Style.LS_BdipInset, 'lw': Style.LW_BdipInset, 'c': Color.BdipInset}
+                _ = [ax.plot(Induction.sigmaMean_Sm[Induction.x == np.min(Induction.x)], Induction.D_km[Induction.x == np.min(Induction.x)], **boundStyle) for ax in allAxes]
+                _ = [ax.plot(Induction.sigmaMean_Sm[Induction.x == np.max(Induction.x)], Induction.D_km[Induction.x == np.max(Induction.x)], **boundStyle) for ax in allAxes]
+                _ = [ax.plot(Induction.sigmaMean_Sm[Induction.y == np.min(Induction.y)], Induction.D_km[Induction.y == np.min(Induction.y)], **boundStyle) for ax in allAxes]
+                _ = [ax.plot(Induction.sigmaMean_Sm[Induction.y == np.max(Induction.y)], Induction.D_km[Induction.y == np.max(Induction.y)], **boundStyle) for ax in allAxes]
+
             plt.tight_layout()
-            fig.savefig(Params.FigureFiles.inductCompare[compChoice], format=FigMisc.figFormat, dpi=FigMisc.dpi)
+            fig.savefig(Params.FigureFiles.inductCompare[compChoice], format=FigMisc.figFormat, dpi=FigMisc.dpi, metadata=FigLbl.meta)
             log.debug(f'Plot saved to file: {Params.FigureFiles.inductCompare[compChoice]}')
             plt.close()
 
@@ -437,23 +498,30 @@ def PlotInductOgram(Induction, Params):
 
         zContours = [axes[0].contour(Induction.sigmaMean_Sm, Induction.D_km, z[i, ...],
                          colors=Color.Induction[T], linestyles=Style.LS_Induction[T],
-                         linewidths=Style.LW_Induction[T], levels=IndParams.GetClevels(fLabel, T))
+                         linewidths=Style.LW_Induction[T], levels=Params.Induct.GetClevels(fLabel, T))
                          for i, T in enumerate(TexcPlotNames)]
         phaseContours = [axes[1].contour(Induction.sigmaMean_Sm, Induction.D_km, Induction.phase[i, ...],
                          colors=Color.Induction[T], linestyles=Style.LS_Induction[T],
-                         linewidths=Style.LW_Induction[T], levels=IndParams.GetClevels('phase', T))
+                         linewidths=Style.LW_Induction[T], levels=Params.Induct.GetClevels('phase', T))
                          for i, T in enumerate(TexcPlotNames)]
         if Params.Induct.inductOtype == 'sigma':
-            [axes[0].clabel(zContours[i], fmt=IndParams.GetCfmt(fLabel, T),
+            [axes[0].clabel(zContours[i], fmt=Params.Induct.GetCfmt(fLabel, T),
                             fontsize=FigMisc.cLabelSize, inline_spacing=FigMisc.cLabelPad)
                             for i, T in enumerate(TexcPlotNames)]
-            [axes[1].clabel(phaseContours[i], fmt=IndParams.GetCfmt('phase', T),
+            [axes[1].clabel(phaseContours[i], fmt=Params.Induct.GetCfmt('phase', T),
                             fontsize=FigMisc.cLabelSize, inline_spacing=FigMisc.cLabelPad)
                             for i, T in enumerate(TexcPlotNames)]
             fNameSigma = Params.FigureFiles.sigmaOnly[fLabel]
         else:
             fNameSigma = Params.FigureFiles.sigma[fLabel]
 
+            if FigMisc.MARK_INDUCT_BOUNDS:
+                boundStyle = {'ls': Style.LS_BdipInset, 'lw': Style.LW_BdipInset, 'c': Color.BdipInset}
+                _ = [ax.plot(Induction.sigmaMean_Sm[Induction.x == np.min(Induction.x)], Induction.D_km[Induction.x == np.min(Induction.x)], **boundStyle) for ax in axes]
+                _ = [ax.plot(Induction.sigmaMean_Sm[Induction.x == np.max(Induction.x)], Induction.D_km[Induction.x == np.max(Induction.x)], **boundStyle) for ax in axes]
+                _ = [ax.plot(Induction.sigmaMean_Sm[Induction.y == np.min(Induction.y)], Induction.D_km[Induction.y == np.min(Induction.y)], **boundStyle) for ax in axes]
+                _ = [ax.plot(Induction.sigmaMean_Sm[Induction.y == np.max(Induction.y)], Induction.D_km[Induction.y == np.max(Induction.y)], **boundStyle) for ax in axes]
+
         if FigMisc.PLOT_V2021 and Induction.bodyname in ['Europa', 'Ganymede', 'Callisto']:
             AddV2021points(Params.Induct, Induction.bodyname, 'sigma', axes)
 
@@ -462,7 +530,7 @@ def PlotInductOgram(Induction, Params):
             axes[1].legend(lines[iSort], FigLbl.legendTexc[iSort], framealpha=FigMisc.cLegendOpacity)
 
         plt.tight_layout()
-        fig.savefig(fNameSigma, format=FigMisc.figFormat, dpi=FigMisc.dpi)
+        fig.savefig(fNameSigma, format=FigMisc.figFormat, dpi=FigMisc.dpi, metadata=FigLbl.meta)
         log.debug(f'Plot saved to file: {fNameSigma}')
         plt.close()
 
@@ -485,16 +553,16 @@ def PlotInductOgram(Induction, Params):
 
             zContours = [axes[0].contour(Induction.x, Induction.y, z[i, ...],
                              colors=Color.Induction[T], linestyles=Style.LS_Induction[T],
-                             linewidths=Style.LW_Induction[T], levels=IndParams.GetClevels(fLabel, T))
+                             linewidths=Style.LW_Induction[T], levels=Params.Induct.GetClevels(fLabel, T))
                              for i, T in enumerate(TexcPlotNames)]
             phaseContours = [axes[1].contour(Induction.x, Induction.y, Induction.phase[i, ...],
                              colors=Color.Induction[T], linestyles=Style.LS_Induction[T],
-                             linewidths=Style.LW_Induction[T], levels=IndParams.GetClevels('phase', T))
+                             linewidths=Style.LW_Induction[T], levels=Params.Induct.GetClevels('phase', T))
                              for i, T in enumerate(TexcPlotNames)]
-            [axes[0].clabel(zContours[i], fmt=IndParams.GetCfmt(fLabel, T),
+            [axes[0].clabel(zContours[i], fmt=Params.Induct.GetCfmt(fLabel, T),
                             fontsize=FigMisc.cLabelSize, inline_spacing=FigMisc.cLabelPad)
                             for i, T in enumerate(TexcPlotNames)]
-            [axes[1].clabel(phaseContours[i], fmt=IndParams.GetCfmt('phase', T),
+            [axes[1].clabel(phaseContours[i], fmt=Params.Induct.GetCfmt('phase', T),
                             fontsize=FigMisc.cLabelSize, inline_spacing=FigMisc.cLabelPad)
                             for i, T in enumerate(TexcPlotNames)]
 
@@ -506,7 +574,7 @@ def PlotInductOgram(Induction, Params):
                 axes[1].legend(lines[iSort], FigLbl.legendTexc[iSort], framealpha=FigMisc.cLegendOpacity)
 
             plt.tight_layout()
-            fig.savefig(Params.FigureFiles.induct[fLabel], format=FigMisc.figFormat, dpi=FigMisc.dpi)
+            fig.savefig(Params.FigureFiles.induct[fLabel], format=FigMisc.figFormat, dpi=FigMisc.dpi, metadata=FigLbl.meta)
             log.debug(f'Plot saved to file: {Params.FigureFiles.induct[fLabel]}')
             plt.close()
 
@@ -665,7 +733,7 @@ def PlotComplexBdip(PlanetList, Params):
                 [axes[iRow, -1].set_xlim(left=0) for iRow in range(3)]
                 [axes[iRow, -1].set_ylim(bottom=0) for iRow in range(3)]
                 plt.tight_layout()
-                fig.savefig(Params.FigureFiles.Bdip['all'], format=FigMisc.figFormat, dpi=FigMisc.dpi)
+                fig.savefig(Params.FigureFiles.Bdip['all'], format=FigMisc.figFormat, dpi=FigMisc.dpi, metadata=FigLbl.meta)
                 log.debug(f'Induced dipole surface strength plot saved to file: {Params.FigureFiles.Bdip["all"]}')
                 plt.close()
 
@@ -761,7 +829,7 @@ def PlotComplexBdip(PlanetList, Params):
                     axes[-1].set_xlim(left=0)
                     axes[-1].set_ylim(bottom=0)
                     plt.tight_layout()
-                    fig.savefig(Params.FigureFiles.Bdip[axComp], format=FigMisc.figFormat, dpi=FigMisc.dpi)
+                    fig.savefig(Params.FigureFiles.Bdip[axComp], format=FigMisc.figFormat, dpi=FigMisc.dpi, metadata=FigLbl.meta)
                     log.debug(f'Induced dipole surface strength plot saved to file: {Params.FigureFiles.Bdip[axComp]}')
                     plt.close()
 
@@ -885,7 +953,7 @@ def PlotMagSurface(PlanetList, Params):
             if not FigMisc.BASYM_WITH_SYM:
                 plt.tight_layout()
                 fName = f'{Params.FigureFiles.MagSurf[FigMisc.vCompMagSurf]}{tFnameEnd}{FigMisc.xtn}'
-                fig.savefig(fName, bbox_inches='tight', format=FigMisc.figFormat, dpi=FigMisc.dpi)
+                fig.savefig(fName, bbox_inches='tight', format=FigMisc.figFormat, dpi=FigMisc.dpi, metadata=FigLbl.meta)
                 log.debug(f'Induced field surface map saved to file: {fName}')
                 plt.close()
 
@@ -957,11 +1025,11 @@ def PlotMagSurface(PlanetList, Params):
                 plt.tight_layout()
                 if FigMisc.BASYM_WITH_SYM:
                     fName = f'{Params.FigureFiles.MagSurfCombo[FigMisc.vCompMagSurf]}{tFnameEnd}{FigMisc.xtn}'
-                    fig.savefig(fName, bbox_inches='tight', format=FigMisc.figFormat, dpi=FigMisc.dpi)
+                    fig.savefig(fName, bbox_inches='tight', format=FigMisc.figFormat, dpi=FigMisc.dpi, metadata=FigLbl.meta)
                     log.debug(f'Symmetric/asymmetric induced field surface maps saved to file: {fName}')
                 else:
                     fName = f'{Params.FigureFiles.MagSurfSym[FigMisc.vCompMagSurf]}{tFnameEnd}{FigMisc.xtn}'
-                    fig.savefig(fName, bbox_inches='tight', format=FigMisc.figFormat, dpi=FigMisc.dpi)
+                    fig.savefig(fName, bbox_inches='tight', format=FigMisc.figFormat, dpi=FigMisc.dpi, metadata=FigLbl.meta)
                     log.debug(f'Symmetric induced field surface map saved to file: {fName}')
 
                 plt.close()
@@ -1012,7 +1080,7 @@ def PlotMagSurface(PlanetList, Params):
                 ax.set_aspect(1)
                 plt.tight_layout()
                 fName = f'{Params.FigureFiles.MagSurfDiff[FigMisc.vCompMagSurf]}{tFnameEnd}{FigMisc.xtn}'
-                fig.savefig(fName, bbox_inches='tight', format=FigMisc.figFormat, dpi=FigMisc.dpi)
+                fig.savefig(fName, bbox_inches='tight', format=FigMisc.figFormat, dpi=FigMisc.dpi, metadata=FigLbl.meta)
                 log.debug(f'Induced field difference surface map saved to file: {fName}')
                 plt.close()
 
@@ -1105,7 +1173,7 @@ def PlotAsym(PlanetList, Params):
             ax.set_aspect(1)
             plt.tight_layout()
             fName = f'{Params.FigureFiles.asym}z{zMean_km:.1f}km{FigMisc.xtn}'
-            fig.savefig(fName, bbox_inches='tight', format=FigMisc.figFormat, dpi=FigMisc.dpi)
+            fig.savefig(fName, bbox_inches='tight', format=FigMisc.figFormat, dpi=FigMisc.dpi, metadata=FigLbl.meta)
             log.debug(f'Asymmetric boundary surface map for z = {zMean_km:.1f} km saved to file: {fName}')
             plt.close()
 
@@ -1190,7 +1258,7 @@ def PlotMagSpectrum(PlanetList, Params):
         [ax.legend() for ax in axes]
 
     plt.tight_layout()
-    fig.savefig(Params.FigureFiles.MagFT, format=FigMisc.figFormat, dpi=FigMisc.dpi)
+    fig.savefig(Params.FigureFiles.MagFT, format=FigMisc.figFormat, dpi=FigMisc.dpi, metadata=FigLbl.meta)
     log.debug(f'Magnetic Fourier spectra plot saved to file: {Params.FigureFiles.MagFT}')
     plt.close()
 
